==> realestate-supervise-common-1.0.0-20190527.033121-2-sources.jar: cn/gtmap/realestate/supervise/entity/TjBdcqzs.java <==
package cn.gtmap.realestate.supervise.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author hqz
 * @version 1.0, 2017/4/10
 * @description 不动产权证书表
 */
@Table(name = "tj_bdcqzs")
public class TjBdcqzs implements Serializable {
    @Id
    //证书编码
    private String zsid;
    //不动产单元号
    private String bdcdyh;
    //不动产权证号
    private String bdcqzh;
    //坐落
    private String zl;
    //权利人名称
    private String qlrmc;
    //权利人证件号
    private String qlrzjh;
    //权属状态
    private String qszt;
    //限制状态
    private String xzzt;
    //用途
    private String yt;
    //一级行政区代码
    private String yjxzq;
    //二级行政区代码
    private String ejxzq;

    public String getZsid() {
        return zsid;
    }

    public void setZsid(String zsid) {
        this.zsid = zsid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getXzzt() {
        return xzzt;
    }

    public void setXzzt(String xzzt) {
        this.xzzt = xzzt;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getYjxzq() {
        return yjxzq;
    }

    public void setYjxzq(String yjxzq) {
        this.yjxzq = yjxzq;
    }

    public String getEjxzq() {
        return ejxzq;
    }

    public void setEjxzq(String ejxzq) {
        this.ejxzq = ejxzq;
    }
}

==> realestate-supervise-common-1.1.0-20251204.005843-70-sources.jar: cn/gtmap/realestate/supervise/entity/TjBdcqzs.java <==
package cn.gtmap.realestate.supervise.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author hqz
 * @version 1.0, 2017/4/10
 * @description 不动产权证书表
 */
@Table(name = "tj_bdcqzs")
public class TjBdcqzs implements Serializable {
    @Id
    //证书编码
    private String zsid;
    //不动产单元号
    private String bdcdyh;
    //不动产权证号
    private String bdcqzh;
    //坐落
    private String zl;
    //权利人名称
    private String qlrmc;
    //权利人证件号
    private String qlrzjh;
    //权属状态
    private String qszt;
    //限制状态
    private String xzzt;
    //用途
    private String yt;
    //一级行政区代码
    private String yjxzq;
    //二级行政区代码
    private String ejxzq;

    //新增业务号
    private  String ywh;


    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getZsid() {
        return zsid;
    }

    public void setZsid(String zsid) {
        this.zsid = zsid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getXzzt() {
        return xzzt;
    }

    public void setXzzt(String xzzt) {
        this.xzzt = xzzt;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getYjxzq() {
        return yjxzq;
    }

    public void setYjxzq(String yjxzq) {
        this.yjxzq = yjxzq;
    }

    public String getEjxzq() {
        return ejxzq;
    }

    public void setEjxzq(String ejxzq) {
        this.ejxzq = ejxzq;
    }
}
